decode_int_prefix

Function decode_int_prefix 

fn decode_int_prefix(bytes: &[u8], start: usize) -> Option<(i64, usize)>
Decode an integer at the given position, returning the value and the index of the position following the decoded integer.